################################################################
# plots for paper
################################################################

rm(list=ls())
memory.limit(4000)

graphics.off()
windows(record=TRUE)

library(signal)

op = par( no.readonly=TRUE )

## on/off switches for producing various plot files
MAKE.BASIS.FUNCTION.PNG  = TRUE
MAKE.EXAMPLE.FITS.PNG    = TRUE
MAKE.BESTMEDWORST.PNG    = TRUE
MAKE.COMPARE.METHODS.PNG = TRUE

#----------------------------------------
# read prepared f5,f1,SVD,NMF... data
#----------------------------------------
DATA = dget("fert.data.dput")
for (k in names(DATA)) assign(k, DATA[[k]])

EST = dget("fert.estimates.dput")

K7 = as.matrix( read.csv("K7.csv", header=T, row.names=1) )
K9 = as.matrix( read.csv("K9.csv", header=T, row.names=1) )

alpha = 12
beta  = 55
age   = alpha:(beta-1)
A     = length(age)

##--------------------------------------------------------------
## first plot @PANDA: 2x1 panels of basis functions K
##--------------------------------------------------------------

K7 = as.matrix(read.csv("K7.csv", header=T, row.names=1))
K9 = as.matrix(read.csv("K9.csv", header=T, row.names=1))

a = as.numeric( dimnames(K7)[[1]])   # fine age grid

if (MAKE.BASIS.FUNCTION.PNG) {
## colors, widths, and types for HFD lines (g=9)
  hue = c(1,2,3,4,5,1,2,3,4)
  ww  = c(3,5,7,3,5,7,3,5,7)
  tt  = c(1,2,1,2,1,2,1,2,1)
  L   = seq(10,50,5)
  
  png("empirical basis functions.png", width=11/1.2, height=11/1.2, units="in", res=300)
      par( mfrow=c(2,1), mai=c(.5,.5,.5,0), bty="l", cex.main=2)
      
    ## IDB first
      ix = 2:8
      matplot( a,  K7, lty=tt[ix], type="l", col=hue[ix], lwd=ww[ix],
                 bty="l", ylim=c(-.75,1.30), xlab="age", ylab="",main="g = 7")
      text( L[ix] + 2.5, 1.30, L[ix], col=hue[ix], cex=2)
      abline(h=0)
      abline(v=seq(0,60,5), h=seq(-2,2,.50), lty=2, lwd=2, col="grey")
    
    ## HFD second
      ix = 1:9
      matplot( a,  K9, lty=tt[ix], type="l", col=hue[ix], lwd=ww[ix],
                 bty="l", ylim=c(-.75,1.30), xlab="age", ylab="", main="g = 9")
      text( L[ix] + 2.5, 1.30, L[ix], col=hue[ix], cex=2)
      abline(h=0)
      abline(v=seq(0,60,5), h=seq(-2,2,.50), lty=2, lwd=2, col="grey")
    
      par(op)
  dev.off()
  
}  # if MAKE.BASIS.FUNCTION.PNG

#-----------------------------------------------------------------
# second plot @KOALA: examples of fitted g=7 and g=9 schedules
#-----------------------------------------------------------------

if (MAKE.EXAMPLE.FITS.PNG) {
  png("example.asfr.png", width=11/1.2, height=11/1.2, units="in", res=300)
      par( mfrow=c(2,1), mai=c(.5,.5,.5,0), bty="l")
    
    ## IDB g=7 case first : Guyana is closest to median sum of sq fitting errors
      sel = "Uruguay"
      ff  = IDB[sel,]
      fstar = K7 %*% ff
    
      plot( a, fstar , type="l", lwd=5, col="red", bty="l", 
             xlab="Age", ylab="ASFR", ylim=c(0,1.15*max(ff)), axes=F,
               main=paste(sel,"2002 (fit from g=7 five-year rates)") )
      axis(1,pos=0, at=seq(10,60,10))
      axis(2)
    
      L = seq(15,45,5)
      segments(L,0,L,ff)
      segments(L,ff,L+5,ff)
      segments(L+5,ff,L+5,0)
      segments(L+5,0,L,0)
          
      G           = outer(L,a, function(LL,xx) { 1 * (LL <= xx) * (xx < LL+5)  })
      dimnames(G) = list(L,a)
      G           = sweep(G,1,apply(G,1,sum),"/")
      
      points(L+2.5, G %*% fstar, pch=16, cex=2.5, col="red") # fitted f5
    
    ## HFD g=9 case second : Finland 1961 is closest to median sum of sq fitting errors
    
      sel = "AUT1952"
      prettysel = "Austria 1952"
      ff = f5[,sel]
      fstar = K9 %*% ff
    
      plot( a, fstar , type="l", lwd=5, col="red", bty="l", 
             xlab="Age", ylab="ASFR", ylim=c(0,1.15*max(ff)), axes=F,
               main=paste(prettysel,"(fit from g=9 five-year rates") )
      axis(1,pos=0, at=seq(10,60,10))
      axis(2)
    
      L = seq(10,50,5)
      segments(L,0,L,ff)
      segments(L,ff,L+5,ff)
      segments(L+5,ff,L+5,0)
      segments(L+5,0,L,0)
          
      G           = outer(L,a, function(LL,xx) { 1 * (LL <= xx) * (xx < LL+5)  })
      dimnames(G) = list(L,a)
      G           = sweep(G,1,apply(G,1,sum),"/")
      
      points(L+2.5, G %*% fstar, pch=16, cex=2.5, col="red")       # fitted f5
      points(12:54+.50, f1[,sel], pch=16, cex=1.40)  # original one-year rates
    
    
        par(op)
    dev.off()
    
} # if MAKE.EXAMPLE.FITS.PNG 
#-----------------------------------------------------------------
# 3rd plot @DINGO: examples of fitted g=9 schedules - worst, median, best
#    use HFD  DEUTE1965 (worst), GBRTENW2009 (very close to median), RUS2003 (best)
#-----------------------------------------------------------------
if (MAKE.BESTMEDWORST.PNG) {
  png("worst-median-best.png", width=11/2.5, height=16/2.5, units="in", res=300)
      par( mfrow=c(3,1), mai=c(.5,.8,.5,.1), bty="l")
    
      sel = c("DEUTE1965", "USA1990", "DEUTW1992")
    
      for (j in sel) {
        ff  = f5[,j]
        fstar = K9 %*% ff
      
        plot( a, fstar , type="l", lwd=5, col="red", bty="l", 
               xlab="Age", ylab="ASFR", ylim=c(0,1.15*max(ff)), axes=F,
                 main=j )
        axis(1,pos=0, at=seq(10,60,10))
        axis(2)
      
        L = seq(10,50,5)
        segments(L,0,L,ff)
        segments(L,ff,L+5,ff)
        segments(L+5,ff,L+5,0)
        segments(L+5,0,L,0)
            
        G           = outer(L,a, function(LL,xx) { 1 * (LL <= xx) * (xx < LL+5)  })
        dimnames(G) = list(L,a)
        G           = sweep(G,1,apply(G,1,sum),"/")
        
        points(L+2.5, G %*% fstar, pch=16, cex=2.5, col="red") # fitted f5
        points(12:54+.50, f1[,j], pch=16, cex=1.40)  # original one-year rates
    
      } # for j
    
     par(op)
 dev.off()
    
} # if MAKE.BESTMEDWORST.PNG


#-----------------------------------------------------------------
# 4th plot @JACKALOPE: 3 methods for Scotland 2004
#-----------------------------------------------------------------\

if (MAKE.COMPARE.METHODS.PNG) {

  make.panel = function(ff,  adj, pts, unadj = NULL, ti="", hue=1) {
    ## unadj, adj and pts must be xy lists
    
    asfr = unadj
    if (is.null(asfr)) asfr = adj
    
    plot(asfr , type="n", lwd=5, bty="l", 
          xlab="Age", ylab="ASFR", ylim=c(0,1.15*max(ff)), axes=F,
          main=ti, cex.main=1.2, xlim=c(10,55))

    L = seq(10,50,5)
    segments(L,  0, L,  ff, lwd=1, col=grey(.55))
    segments(L,  ff,L+5,ff, lwd=1, col=grey(.55))
    segments(L+5,ff,L+5,0,  lwd=1, col=grey(.55))
    segments(L+5,0, L,  0,  lwd=1, col=grey(.55))
    
    
    if (!is.null(unadj)) lines(unadj, lwd=2, lty=2)
    lines(adj,col=hue, lwd=3)
    points(pts,col=hue, pch=1.3, cex=1)
    
    
    #   lines(age+.5, fhat.HFDsplit, col="red", lwd=4, type="b", pch="H")
    #   lines(age+.5, fhat.Beers, col="seagreen", lwd=4, type="b", pch="B")
    
    axis(1,pos=0, at=seq(10,60,10))
    axis(2, pos=10,at=c(0,.05,.10,.15,.20), labels=c("0",".05", ".10",".15",".20"))
    
    ok = !DATA$f1.split[,j]
    points((12:54+.50)[ok], f1[ok,j], pch=16, cex=.75)  # original one-year rates
    
  }
  
  png("Scotland 2004 compare methods.png", width=22/2.5, height=14/2.5, units="in", res=300)
  
      par( mfrow=c(2,2), bty="l", mai=c(.40,.40,.15,.10))

  #########
      j = "GBR_SCO2004"
#       j = sample( dimnames(DATA$f5)[[2]], 1)
#       j = "AUT1952"
      print(j)
  
    
      ff  = DATA$f5[,j]
      a   = seq(12.25, 54.75, .50)
      
      # NW panel: Beers
      make.panel( ff, 
                  adj=list(x=12:54+.50, y=EST$Beers$HFD$adj[,j]),
                  pts=list(x=12:54+.50, y=EST$Beers$HFD$adj[,j]),
                  ti="Beers",
                  hue="seagreen")
  
#       # NE panel: HFD split
      fineHFD = fine.hfd.split( ff, delta=.10)
      make.panel( ff, 
                  adj= fineHFD,
                  pts=list(x=12:54+.50, y=EST$HFDsplit$HFD[,j]),
                  ti="HFD Protocol",
                  hue="red")
    
#       # SW panel: CS 
    fineCS = list(x=as.numeric(dimnames(K9)[[1]]),  
                  y = K9 %*% ff)

  
    make.panel( ff, 
                adj=fineCS,
                pts=list(x=12:54+.50, y=EST$CS$HFD$unadj[,j]),
                ti="Calibrated Spline",
                hue="navy")
  
 ## customize this panel a bit with a polygon
     polygon(fineCS, col=grey(.80), border="navy")
  
      L = seq(10,50,5)
      segments(L,  0, L,  ff, lwd=1, col=grey(.55))
      segments(L,  ff,L+5,ff, lwd=1, col=grey(.55))
      segments(L+5,ff,L+5,0,  lwd=1, col=grey(.55))
      segments(L+5,0, L,  0,  lwd=1, col=grey(.55))
    
     points(12:54+.50, EST$CS$HFD$unadj[,j], col="navy", pch=1.3)
     points( 12:54+.5, DATA$f1[,j], pch=16, cex=.65)
  
  
## SE panel: comparative 1fx errors
      my.cumsum = function(y) {
        y[is.na(y)] = 0
        cumsum(y^2)
      }
  
      eB = c(0,
             my.cumsum( abs(EST$Beers$HFD$adj[,j] - DATA$f1[,j])))
      eH = c(0,
             my.cumsum( abs(EST$HFDsplit$HFD[,j] - DATA$f1[,j]) ))
      eC = c(0,
             my.cumsum( abs(EST$CS$HFD$unadj[,j] - DATA$f1[,j]) ))
                    
      rr = range(0, eB, eH, eC, na.rm=T)
  
      plot( 11:54+.50, eB, type="n", axes=F,ylim=c(0,.0006),xlim=c(10,55),
               xlab="Age", main="Sum of Sq Errors (x 100,000)")
             
      axis(1, pos=0, at=seq(10,60,10), label=paste(seq(10,60,10)))
      axis(2, pos=10, at=seq(0,.00050,.00025),label=c("0","25","50"))

      polygon( list(x = c(11:54+.50, 54.50), y=c(eC,0)) , col=grey(.80) , border=NA )
      lines(11:54+.50, eC, col="navy")
  
      lines(11:54+.50, eB, type="l", col="seagreen", pch="B", lwd=3)
  
      lines(11:54+.50, eH, type="l", col="red", pch="H", lwd=3)
  
#      lines( 11:54+.50, eC, type="o", col="navy", pch="C", lwd=3 )

      text(35, 6e-5, "Calibrated Spline", cex=1.1, adj=0)
      text(35, 22e-5, "HFD Protocol",     cex=1.1, adj=0, col="red")
      text(35, 42e-5, "Beers",            cex=1.1, adj=0, col="seagreen")
  

  
      par(op)
  
  dev.off()
  
} # if MAKE.COMPARE.METHODS.PNG

