%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Subversion file information - please do not edit this block
%% $Rev: 880 $
%% $Date: 2010-12-15 15:40:06 +0100 (Wed, 15 Dec 2010) $
%% $Author: nash $
%% $Id: IPF.Rd 880 2010-12-15 14:40:06Z nash $
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{IPF}
\alias{IPF}
\title{
  Iterative proportional fitting with grouped rows
}
\description{
  Iterative proportional fitting is a method of adjusting the cells in a matrix
  such that rows and columns sum to fit some predefined marginal totals. This implementation
  assumes that the sums of the columns are equal to the desired marginal totals: the
  marginal totals for the rows are supplied as argument \code{v}. Within the matrix, the
  fitting may be performed using submatrices defined as groups of rows, i.e. groups of rows
  for which the column totals are assumed to be correct and there should therefore be no
  reallocation of values over the group boundaries.
}
\usage{
IPF(M, v, groups)
}
\arguments{
  \item{M}{
  An array of values defining the input to the fitting
}
  \item{v}{
  A vector of row totals to which the sums of the rows in \code{M} should be adjusted
  to match. Length must be the same as the number of rows in \code{M}.
}
  \item{groups}{
  A vector of numeric group IDs defining the groups of rows in which IPF is to be performed.
  Length must be the same as the number of rows in \code{M} (i.e. each row in \code{M} must
  be allocated to exactly one numeric group). 
}
}
\value{
  An array with dimensions of \code{M} with cell values adjusted according to the iterative
  proportional fitting procedure in groups defined by \code{groups}.
}
\references{
  Jasilioniene et al.: Methods Protocol for the Human Fertility Database.
  Available from \url{http://www.humanfertility.org} 
}
\author{
  Dmitri Jdanov \email{jdanov@demogr.mpg.de}
}
\seealso{
  \code{\link{indb.IPF}} for how the IPF may be used with HFD data.
}
\examples{
  IPF(M = array(1:24, dim = c(6,4)), v = c(45, 40, 50, 48, 59, 58), groups = c(1, 1, 1, 1, 2, 2)) 
}

