################################################################################
##
## Subversion file information - please do not edit this block
## $Rev: 882 $
## $Date: 2011-01-10 09:06:33 +0100 (Mon, 10 Jan 2011) $
## $Author: nash $
## $Id: aggregateLatereg.R 882 2011-01-10 08:06:33Z nash $
##
################################################################################

aggregateLatereg <-
function(indb) {
## aggregate late registered births to their year of occurence and birth orders
## UNK and 1 to 5+
##
## @inputs
## - indb: input database containing late registered births
## @returns
## - input database with late registration births aggregated by their original
##   shapes and ages to the year of occurence and birth orders 1 to 5+

  indbL <- indb[indb$Year != indb$YearReg, ]
  indb <- indb[indb$Year == indb$YearReg, ]

  if (nrow(indbL) > 0) {
    pName = indbL[1, "PopName"]
    indbL[indbL$BirthOrder >= 5, "BirthOrder"] <- 5
    indbL[indbL$BirthOrder >= 5, "OrderInt"] <- '+'
    indbL <- aggregate(indbL$Births,
                       list(Area = indbL$Area,
                            Year = indbL$Year,
                            Age = indbL$Age,
                            AgeInt = indbL$AgeInt,
                            Lexis = indbL$Lexis,
                            BirthOrder = indbL$BirthOrder,
                            OrderInt = indbL$OrderInt),
                       sum)
    names(indbL)[ncol(indbL)] <- "Births"
    indbL <- indbL[indbL$Births > 0, ] # aggregate produces many rows with Births==0
    indbL$PopName <- pName
    indbL$YearReg <- -1
    indbL$DurInt <- indbL$PrevBirth <- '.'
    indbL$Vital <- 1
    indbL$Access <- 'O'
    indbL$Note3 <- indbL$Note2 <- indbL$Note1 <- '.'
    indbL$RefCode <- 99
    indbL$LDB <- 1
    indbL <- indbL[, c(9, 1:2, 10, 3:7, 11:13, 8, 14:19)]
  }

  indb <- rbind(indb, indbL)
  indb <- indb[order(indb$Year, indb$BirthOrder, indb$Age), ]
  return(indb)
}

